<?php
// This file is part of Moodle - https://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <https://www.gnu.org/licenses/>.

/**
 * Block activity_users is defined here.
 *
 * @package     block_activity_users
 * @copyright   2024 Your Name <you@example.com>
 * @license     https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class block_activity_users extends block_base {

    /**
     * Initializes class member variables.
     */
    public function init() {
        // Needed by Moodle to differentiate between blocks.
//        $this->title = get_string('pluginname', 'block_activity_users');
    }

    /**
     * Returns the block contents.
     *
     * @return stdClass The block contents.
     */
    public function get_content() {
        global $PAGE;
        $PAGE->requires->js('/blocks/activity_users/js/main.js');
        $PAGE->requires->css('/blocks/activity_users/css/style.css');

        $back = new moodle_url('/blocks/activity_users/aset/back.png');
        $next = new moodle_url('/blocks/activity_users/aset/next.png');
        $menu = new moodle_url('/blocks/activity_users/aset/option.png');

        if ($this->content !== null) {
            return $this->content;
        }

        if (empty($this->instance)) {
            $this->content = '';
            return $this->content;
        }

        $this->content = new stdClass();
        $this->content->items = array();
        $this->content->icons = array();
        $this->content->footer = '';


        include 'back/user_activity.php';

        if (!empty($this->config->text)) {
            $this->content->text = $this->config->text;
        } else {
            $text = '
                <div class="d-flex justify-content-between align-items-center">
                  <h4>User Activity</h4>
                  <div>See All</div>
                </div>
                <div class="row">';

            foreach ($user_activity as $item){
                $text .='   <div class="col-4 mt-3">
                    <div class="card p-2" style="border:1px solid rgba(0, 0, 0, 0.05)">
                      <div class="d-flex justify-content-between align-content-center">
                        <div class="d-flex align-items-center">
                          <div style="width:30px;height:30px" class="text-center mt-2 rounded-circle">
                            <img class="rounded-circle" src="'.new moodle_url("/user/pix.php/". $item->id . "/f1.jpg").'">
                          </div>
                          <div class="mt-1 ml-2">'.$item->nama_user.'</div>
                        </div>
                        <div class="mt-2"><img style="width: 15px;" src="'.$menu.'"></div>
                      </div>
                      <div class="d-flex justify-content-between align-items-center mt-2">
                          <div class="mr-1" style="'.(count($item->course) > 2 ? '' : 'display:none').'"><img id="slideback" onclick="sideScroll('.$item->id.','.'0'.')" style="width: 15px;" src="'.$back.'"></div>
                         <div id="dataactivity'.$item->id.'" style="width:90%;display: flex;overflow-x:hidden">';
                foreach ($item->course as $course) {
                    $text .= '
                            <div>
                              <div style="border:1px solid rgba(0, 0, 0, 0.05);width:200px" class="ml-2 card p-2">
                                <div>'.$course->nama_course.'</div>
                                <div style="color:'.($course->persentase == 100 ? '#00B151' : ($course->persentase == 0 ? '#C50000' : '#EC9C00')).'">'.$course->persentase.'%</div>
                                <div style="height:10px;border-radius:10px;width:100%;background-color: #F2F2F2">
                                 <div style="height:10px;border-radius:10px;width:'.($course->persentase == 0 ? '2' : $course->persentase).'%;background-color: '.($course->persentase == 100 ? '#00B151' : ($course->persentase == 0 ? '#C50000' : '#EC9C00')).'"></div>
                                </div>
                              </div>
                            </div>
                          ';
                }
                $text .='      </div><div style="'.(count($item->course) > 2 ? '' : 'display:none').'" class="ml-1"><img onclick="sideScroll('.$item->id.','.'1'.')" id="slide" style="width: 15px;" src="'.$next.'"></div>
                      </div>
                    </div>
                  </div>';
            }
            $text .= '</div>
            ';
            $this->content->text = $text;
        }

        return $this->content;
    }

    /**
     * Defines configuration data.
     *
     * The function is called immediately after init().
     */
    public function specialization() {

        // Load user defined title and make sure it's never empty.
        if (empty($this->config->title)) {
//            $this->title = get_string('pluginname', 'block_activity_users');
        } else {
//            $this->title = $this->config->title;
        }
    }

    /**
     * Enables global configuration of the block in settings.php.
     *
     * @return bool True if the global configuration is enabled.
     */
    public function has_config() {
        return true;
    }

    /**
     * Sets the applicable formats for the block.
     *
     * @return string[] Array of pages and permissions.
     */
    public function applicable_formats() {
        return array(
            'all' => true,
        );
    }

    function _self_test(){
        return true;
    }
}
